*==============================================================================*
*                            Description of dofile                             *
/*=============================================================================*

This dofile generates Figure 2 presented in the article.

The structure of this dofile is as follows:

	1. Setting paths and opening data
	2. Earnings analysis (Figure 2)
	
*=============================================================================*/
*                        1. Setting paths and opening data                     *
*==============================================================================*

clear all
set more off
global dir "SET YOUR PATH"
global pathd "$dir/data" 
global paths "$dir/dofiles" 
global pathf "$dir/figures" 
global pathp "$dir/posted" 
global patht "$dir/tables" 
set scheme plotplainblind

use "$pathp/working.dta", clear

global controls ib3.edu workexp tenure ib4.pt ib12.industry ib7.worksize 

********************************************************************************
*					                 FIGURE 2                            	   *
********************************************************************************

**UNADJUSTED**
reg log_earn i.aut##i.man 
margins, at(aut=(1 2 3 4 5) man=(0 1)) post
est store m1

**ADJUSTED**
reg log_earn i.aut##i.man $controls
margins, at(aut=(1 2 3 4 5) man=(0 1)) post
est store m2

//Figure 2 
coefplot (m1, color(black%80) ciopts(color(turquoise%100) recast(rcap))) (m2, color(turquoise%80) ciopts(color(black%100) recast(rcap))), recast(bar) barwidth(0.28) vertical levels(83) coeflabels(1._at=`""Women" "No aut""' 2._at=`""Men" "No aut""' 3._at=`""Women" "Some""' 4._at=`""Men" "Some""' 5._at=`""Women" "No cntrl""' 6._at=`""Men" "No cntrl""' 7._at=`""Women" "Human""' 8._at=`""Men" "Human""' 9._at=`""Women" "Org""' 10._at=`""Men" "Org""', labsize(small)) title("Hourly earnings (logged)", size(small)) xtitle("") ytitle("", size(vsmall)) legend(position(6) rows(1) size(vsmall)) plotlabels("w/out controls" "w/ controls") 
graph export "$pathf/Figure 2.tif", replace

//end dofile