*==============================================================================*
*                            Description of dofile                             *
/*=============================================================================*

This dofile runs the main analyses and generates Figure 1 and Table 2 presented 
in the article, and Table S1 presented in the supplement to the article. 

The structure of this dofile is as follows:

	1. Setting paths and opening data
	2. Main analysis (Figure 1, Table 2, Table S1)
	
*=============================================================================*/
*                        1. Setting paths and opening data                     *
*==============================================================================*

clear all
set more off
global dir "SET YOUR PATH"
global pathd "$dir/data" 
global paths "$dir/dofiles" 
global pathf "$dir/figures" 
global pathp "$dir/posted" 
global patht "$dir/tables" 
set scheme plotplainblind

use "$pathp/working.dta", clear

global controls1 ib3.edu workexp tenure 
global controls2 ib3.edu workexp tenure ib4.pt ib12.industry ib7.worksize 

*=============================================================================*/
*                                    FIGURE 1                                  *
*==============================================================================*

***some supervisory tasks***
quietly mlogit aut i.man 
margins man, predict(outcome(2)) post
est store m1 
mlincom 2-1 
*
quietly mlogit aut i.man $controls1
margins man, predict(outcome(2)) post
est store m2
mlincom 2-1 
*
quietly mlogit aut i.man $controls2
margins man, predict(outcome(2)) post
est store m3
mlincom 2-1 
		
//FIG1_1
coefplot (m1, color(black%80) ciopts(color(turquoise%100) recast(rcap))) (m2, color(turquoise%80) ciopts(color(black%100) recast(rcap))) (m3, color(turquoise%40) ciopts(color(black%100) recast(rcap))), recast(bar) barwidth(0.23) vertical levels(83) title("Some supervisory tasks", size(small)) xtitle("") ytitle("Probability of Having Authority", size(small)) legend(position(6) rows(1) size(vsmall)) plotlabels("w/out controls" "w/ individual controls" "w/ individual and job controls") name(fig1_1, replace)

***largely supervisory, no control over resources***
quietly mlogit aut i.man 
margins man, predict(outcome(3)) post
est store m1
mlincom 2-1 
*
quietly mlogit aut i.man $controls1
margins man, predict(outcome(3)) post
est store m2
mlincom 2-1 
*
quietly mlogit aut i.man $controls2
margins man, predict(outcome(3)) post 
est store m3 
mlincom 2-1 
		
//FIG1_2
coefplot (m1, color(black%80) ciopts(color(turquoise%100) recast(rcap))) (m2, color(turquoise%80) ciopts(color(black%100) recast(rcap))) (m3, color(turquoise%40) ciopts(color(black%100) recast(rcap))), recast(bar) barwidth(0.23) vertical levels(83) title("Largely supervisory" "No control over resources", size(small)) xtitle("") ytitle("", size(small)) ylab(.01 (.01) .05) legend(position(6) rows(1) size(vsmall)) plotlabels("w/out controls" "w/ individual controls" "w/ individual and job controls") name(fig1_2, replace)

***largely supervisory, control over human resources***
quietly mlogit aut i.man 
margins man, predict(outcome(4)) post 
est store m1
mlincom 2-1 
*
quietly mlogit aut i.man $controls1
margins man, predict(outcome(4)) post
est store m2 
mlincom 2-1 
*
quietly mlogit aut i.man $controls2
margins man, predict(outcome(4)) post
est store m3 
mlincom 2-1 

//FIG1_3
coefplot (m1, color(black%80) ciopts(color(turquoise%100) recast(rcap))) (m2, color(turquoise%80) ciopts(color(black%100) recast(rcap))) (m3, color(turquoise%40) ciopts(color(black%100) recast(rcap))), recast(bar) barwidth(0.23) vertical levels(83) title("Largely supervisory" "Control over human resources", size(small)) xtitle("") ytitle("Probability of Having Authority", size(small)) ylab(.01 (.01) .05) legend(position(6) rows(1) size(vsmall)) plotlabels("w/out controls" "w/ individual controls" "w/ individual and job controls") name(fig1_3, replace)

***largely supervisory, control over organizational resources***
quietly mlogit aut i.man 
margins man, predict(outcome(5)) post 
est store m1
mlincom 2-1 
*
quietly mlogit aut i.man $controls1
margins man, predict(outcome(5)) post
est store m2 
mlincom 2-1 
*
quietly mlogit aut i.man $controls2
margins man, predict(outcome(5)) post
est store m3 
mlincom 2-1 

//FIG1_4 
coefplot (m1, color(black%80) ciopts(color(turquoise%100) recast(rcap))) (m2, color(turquoise%80) ciopts(color(black%100) recast(rcap))) (m3, color(turquoise%40) ciopts(color(black%100) recast(rcap))), recast(bar) barwidth(0.23) vertical levels(83) title("Largely supervisory" "Control over organizational resources", size(small)) xtitle("") ytitle("", size(small)) ylab(.01 (.01) .05) legend(position(6) rows(1) size(vsmall)) plotlabels("w/out controls" "w/ individual controls" "w/ individual and job controls") name(fig1_4, replace)

//Figure 1 
grc1leg fig1_1 fig1_2 fig1_3 fig1_4, row(2) legendfrom(fig1_1) iscale(0.7) graphregion(margin(l=1 r=2 b=3 t=10)) 
graph export "$pathf/Figure 1.tif", replace

*=============================================================================*/
*                               TABLE 2 & TABLE S1                             *
*==============================================================================*

mlogit aut i.man $controls2, base(1)
predict xb1, xb outcome(#2) //some supervisory tasks 
predict xb2, xb outcome(#3) //largely supervisory, no control over resources
predict xb3, xb outcome(#4) //largely supervisory, control over human resources
predict xb4, xb outcome(#5) //largely supervisory, control over organizational resources
//some supervisory tasks 
reg xb1 i.man
eststo m1_1
reg xb1 i.man $controls1
eststo m1_2
reg xb1 i.man $controls2
eststo m1_3
//largely supervisory, no control over resources
reg xb2 i.man
eststo m2_1
reg xb2 i.man $controls1
eststo m2_2
reg xb2 i.man $controls2
eststo m2_3
//largely supervisory, control over human resources
reg xb3 i.man
eststo m3_1
reg xb3 i.man $controls1
eststo m3_2
reg xb3 i.man $controls2
eststo m3_3
//largely supervisory, control over organizational resources
reg xb4 i.man
eststo m4_1
reg xb4 i.man $controls1
eststo m4_2
reg xb4 i.man $controls2
eststo m4_3
drop xb*

//Table 2
esttab m1_1 m1_2 m1_3 m2_1 m2_2 m2_3 m3_1 m3_2 m3_3 m4_1 m4_2 m4_3 using "$patht\Table 2.rtf", star(* 0.05 ** 0.01 *** 0.001) eform se(3) keep (1.man) varlabels(1.man "Man") mtitle("Model 1" "Model 2" "Model 3" "Model 1" "Model 2" "Model 3" "Model 1" "Model 2" "Model 3" "Model 1" "Model 2" "Model 3") title("Table 2. The gender gap across type authority (reference category = no supervisory tasks)") obslast addnotes("Source: Statistics Netherlands, own calculations." "Note: Model 1 shows the controls-unadjusted gender gap. Model 2 controls for education, work experience, and tenure with current employer. Model 3 additionally adjusts for part-time factor, industry, and workplace size. Coefficients are estimated using the linear predictor approach (Breen, Karlson, and Holm 2018).") replace 

***
//Table S1
esttab m1_1 m1_2 m1_3 m2_1 m2_2 m2_3 m3_1 m3_2 m3_3 m4_1 m4_2 m4_3 using "$patht\Table S1.rtf", star(* 0.05 ** 0.01 *** 0.001) eform se(3) keep (1.man 1.edu 2.edu 4.edu workexp tenure 1.pt 2.pt 3.pt 1.industry 2.industry 3.industry 4.industry 5.industry 6.industry 7.industry 8.industry 9.industry 10.industry 11.industry 13.industry 1.worksize 2.worksize 3.worksize 4.worksize 5.worksize 6.worksize) varlabels(1.man "Man" 1.edu "Lower secondary" 2.edu "Higher secondary" 4.edu "Master" workexp "Work experience" tenure "Tenure with current employer" 1.pt "0-40%" 2.pt "41-60%" 3.pt "61-80%" 1.industry "Agriculture & Fishery" 2.industry "Manufacturing & Energy" 3.industry "Construction" 4.industry "Trade" 5.industry "Transport & Storage" 6.industry "Catering" 7.industry "Information & Communication" 8.industry "Financial Services" 9.industry "Business Services" 10.industry "Public Administration" 11.industry "Education" 13.industry "Culture" 1.worksize "less than 10" 2.worksize "10-19" 3.worksize "20-49" 4.worksize "50-99" 5.worksize "100-249" 6.worksize "250-999") mtitle("Model 1" "Model 2" "Model 3" "Model 1" "Model 2" "Model 3" "Model 1" "Model 2" "Model 3" "Model 1" "Model 2" "Model 3") title("Table S1. Regression coefficients authority gender gaps (reference category = no supervisory tasks); full table") obslast addnotes("Data source: Statistics Netherlands, own calculations." "Note: Model 1 shows the controls-unadjusted gender gap. Model 2 controls for education, work experience, and tenure with current employer. Model 3 additionally adjusts for part-time factor, industry, and workplace size. Coefficients are estimated using the linear predictor approach (Breen, Karlson, and Holm 2018).") replace 

***bootstrap standard errors (Table 2 and Table S1 manually adapted)***

*bootstrap SE for Linear Predictor Approach Authority --> some supervisory tasks
cap progr drop bsxb //erase any stored programs
progr define bsxb, rclass //program starts
//step1. run "full" model and save linear predictor
mlogit aut i.man $controls2, base(1) 
cap drop xb
predict xb, outcome(#2) xb
//step2. run models and save parameters of interest relevant for inference
reg xb i.man
return scalar m1_man=_b[1.man]
reg xb i.man $controls1
return scalar m2_man=_b[1.man]
return scalar m2_edu1=_b[1.edu]
return scalar m2_edu2=_b[2.edu]
return scalar m2_edu4=_b[4.edu]
return scalar m2_workexp=_b[workexp]
return scalar m2_tenure=_b[tenure]
reg xb i.man $controls2
return scalar m3_man=_b[1.man]
return scalar m3_edu1=_b[1.edu]
return scalar m3_edu2=_b[2.edu]
return scalar m3_edu4=_b[4.edu]
return scalar m3_workexp=_b[workexp]
return scalar m3_tenure=_b[tenure]
return scalar m3_pt1=_b[1.pt]
return scalar m3_pt2=_b[2.pt]
return scalar m3_pt3=_b[3.pt]
return scalar m3_industry1=_b[1.industry]
return scalar m3_industry2=_b[2.industry]
return scalar m3_industry3=_b[3.industry]
return scalar m3_industry4=_b[4.industry]
return scalar m3_industry5=_b[5.industry]
return scalar m3_industry6=_b[6.industry]
return scalar m3_industry7=_b[7.industry]
return scalar m3_industry8=_b[8.industry]
return scalar m3_industry9=_b[9.industry]
return scalar m3_industry10=_b[10.industry]
return scalar m3_industry11=_b[11.industry]
return scalar m3_industry13=_b[13.industry]
return scalar m3_worksize1=_b[1.worksize]
return scalar m3_worksize2=_b[2.worksize]
return scalar m3_worksize3=_b[3.worksize]
return scalar m3_worksize4=_b[4.worksize]
return scalar m3_worksize5=_b[5.worksize]
return scalar m3_worksize6=_b[6.worksize]
drop xb
end //program ends
//run bootstrap program:
bs m1_man=r(m1_man) m2_man=r(m2_man) m3_man=r(m3_man) ///
m2_edu1=r(m2_edu1) m3_edu1=r(m3_edu1) ///
m2_edu2=r(m2_edu2) m3_edu2=r(m3_edu2) ///
m2_edu4=r(m2_edu4) m3_edu4=r(m3_edu4) ///
m2_workexp=r(m2_workexp) m3_workexp=r(m3_workexp) ///
m2_tenure=r(m2_tenure) m3_tenure=r(m3_tenure) ///
m3_pt1=r(m3_pt1) m3_pt2=r(m3_pt2) m3_pt3=r(m3_pt3) ///
m3_industry1=r(m3_industry1) ///
m3_industry2=r(m3_industry2) ///
m3_industry3=r(m3_industry3) ///
m3_industry4=r(m3_industry4) ///
m3_industry5=r(m3_industry5) ///
m3_industry6=r(m3_industry6) ///
m3_industry7=r(m3_industry7) ///
m3_industry8=r(m3_industry8) ///
m3_industry9=r(m3_industry9) ///
m3_industry10=r(m3_industry10) ///
m3_industry11=r(m3_industry11) ///
m3_industry13=r(m3_industry13) ///
m3_worksize1=r(m3_worksize1) ///
m3_worksize2=r(m3_worksize2) ///
m3_worksize3=r(m3_worksize3) ///
m3_worksize4=r(m3_worksize4) ///
m3_worksize5=r(m3_worksize5) ///
m3_worksize6=r(m3_worksize6) ///
,reps(500) seed(1001): bsxb, all
bs, eform

****

*bootstrap SE for Linear Predictor Approach Authority --> largely supervisory, no control over resources
cap progr drop bsxb //erase any stored programs
progr define bsxb, rclass //program starts
//step1. run "full" model and save linear predictor
mlogit aut i.man $controls2, base(1) 
cap drop xb
predict xb, outcome(#3) xb
//step2. run models and save parameters of interest relevant for inference
reg xb i.man
return scalar m1_man=_b[1.man]
reg xb i.man $controls1
return scalar m2_man=_b[1.man]
return scalar m2_edu1=_b[1.edu]
return scalar m2_edu2=_b[2.edu]
return scalar m2_edu4=_b[4.edu]
return scalar m2_workexp=_b[workexp]
return scalar m2_tenure=_b[tenure]
reg xb i.man $controls2
return scalar m3_man=_b[1.man]
return scalar m3_edu1=_b[1.edu]
return scalar m3_edu2=_b[2.edu]
return scalar m3_edu4=_b[4.edu]
return scalar m3_workexp=_b[workexp]
return scalar m3_tenure=_b[tenure]
return scalar m3_pt1=_b[1.pt]
return scalar m3_pt2=_b[2.pt]
return scalar m3_pt3=_b[3.pt]
return scalar m3_industry1=_b[1.industry]
return scalar m3_industry2=_b[2.industry]
return scalar m3_industry3=_b[3.industry]
return scalar m3_industry4=_b[4.industry]
return scalar m3_industry5=_b[5.industry]
return scalar m3_industry6=_b[6.industry]
return scalar m3_industry7=_b[7.industry]
return scalar m3_industry8=_b[8.industry]
return scalar m3_industry9=_b[9.industry]
return scalar m3_industry10=_b[10.industry]
return scalar m3_industry11=_b[11.industry]
return scalar m3_industry13=_b[13.industry]
return scalar m3_worksize1=_b[1.worksize]
return scalar m3_worksize2=_b[2.worksize]
return scalar m3_worksize3=_b[3.worksize]
return scalar m3_worksize4=_b[4.worksize]
return scalar m3_worksize5=_b[5.worksize]
return scalar m3_worksize6=_b[6.worksize]
drop xb
end //program ends
//run bootstrap program:
bs m1_man=r(m1_man) m2_man=r(m2_man) m3_man=r(m3_man) ///
m2_edu1=r(m2_edu1) m3_edu1=r(m3_edu1) ///
m2_edu2=r(m2_edu2) m3_edu2=r(m3_edu2) ///
m2_edu4=r(m2_edu4) m3_edu4=r(m3_edu4) ///
m2_workexp=r(m2_workexp) m3_workexp=r(m3_workexp) ///
m2_tenure=r(m2_tenure) m3_tenure=r(m3_tenure) ///
m3_pt1=r(m3_pt1) m3_pt2=r(m3_pt2) m3_pt3=r(m3_pt3) ///
m3_industry1=r(m3_industry1) ///
m3_industry2=r(m3_industry2) ///
m3_industry3=r(m3_industry3) ///
m3_industry4=r(m3_industry4) ///
m3_industry5=r(m3_industry5) ///
m3_industry6=r(m3_industry6) ///
m3_industry7=r(m3_industry7) ///
m3_industry8=r(m3_industry8) ///
m3_industry9=r(m3_industry9) ///
m3_industry10=r(m3_industry10) ///
m3_industry11=r(m3_industry11) ///
m3_industry13=r(m3_industry13) ///
m3_worksize1=r(m3_worksize1) ///
m3_worksize2=r(m3_worksize2) ///
m3_worksize3=r(m3_worksize3) ///
m3_worksize4=r(m3_worksize4) ///
m3_worksize5=r(m3_worksize5) ///
m3_worksize6=r(m3_worksize6) ///
,reps(500) seed(1001): bsxb, all
bs, eform

****

*bootstrap SE for Linear Predictor Approach Authority --> largely supervisory, control over human resources
cap progr drop bsxb //erase any stored programs
progr define bsxb, rclass //program starts
//step1. run "full" model and save linear predictor
mlogit aut i.man $controls2, base(1) 
cap drop xb
predict xb, outcome(#4) xb
//step2. run models and save parameters of interest relevant for inference
reg xb i.man
return scalar m1_man=_b[1.man]
reg xb i.man $controls1
return scalar m2_man=_b[1.man]
return scalar m2_edu1=_b[1.edu]
return scalar m2_edu2=_b[2.edu]
return scalar m2_edu4=_b[4.edu]
return scalar m2_workexp=_b[workexp]
return scalar m2_tenure=_b[tenure]
reg xb i.man $controls2
return scalar m3_man=_b[1.man]
return scalar m3_edu1=_b[1.edu]
return scalar m3_edu2=_b[2.edu]
return scalar m3_edu4=_b[4.edu]
return scalar m3_workexp=_b[workexp]
return scalar m3_tenure=_b[tenure]
return scalar m3_pt1=_b[1.pt]
return scalar m3_pt2=_b[2.pt]
return scalar m3_pt3=_b[3.pt]
return scalar m3_industry1=_b[1.industry]
return scalar m3_industry2=_b[2.industry]
return scalar m3_industry3=_b[3.industry]
return scalar m3_industry4=_b[4.industry]
return scalar m3_industry5=_b[5.industry]
return scalar m3_industry6=_b[6.industry]
return scalar m3_industry7=_b[7.industry]
return scalar m3_industry8=_b[8.industry]
return scalar m3_industry9=_b[9.industry]
return scalar m3_industry10=_b[10.industry]
return scalar m3_industry11=_b[11.industry]
return scalar m3_industry13=_b[13.industry]
return scalar m3_worksize1=_b[1.worksize]
return scalar m3_worksize2=_b[2.worksize]
return scalar m3_worksize3=_b[3.worksize]
return scalar m3_worksize4=_b[4.worksize]
return scalar m3_worksize5=_b[5.worksize]
return scalar m3_worksize6=_b[6.worksize]
drop xb
end //program ends
//run bootstrap program:
bs m1_man=r(m1_man) m2_man=r(m2_man) m3_man=r(m3_man) ///
m2_edu1=r(m2_edu1) m3_edu1=r(m3_edu1) ///
m2_edu2=r(m2_edu2) m3_edu2=r(m3_edu2) ///
m2_edu4=r(m2_edu4) m3_edu4=r(m3_edu4) ///
m2_workexp=r(m2_workexp) m3_workexp=r(m3_workexp) ///
m2_tenure=r(m2_tenure) m3_tenure=r(m3_tenure) ///
m3_pt1=r(m3_pt1) m3_pt2=r(m3_pt2) m3_pt3=r(m3_pt3) ///
m3_industry1=r(m3_industry1) ///
m3_industry2=r(m3_industry2) ///
m3_industry3=r(m3_industry3) ///
m3_industry4=r(m3_industry4) ///
m3_industry5=r(m3_industry5) ///
m3_industry6=r(m3_industry6) ///
m3_industry7=r(m3_industry7) ///
m3_industry8=r(m3_industry8) ///
m3_industry9=r(m3_industry9) ///
m3_industry10=r(m3_industry10) ///
m3_industry11=r(m3_industry11) ///
m3_industry13=r(m3_industry13) ///
m3_worksize1=r(m3_worksize1) ///
m3_worksize2=r(m3_worksize2) ///
m3_worksize3=r(m3_worksize3) ///
m3_worksize4=r(m3_worksize4) ///
m3_worksize5=r(m3_worksize5) ///
m3_worksize6=r(m3_worksize6) ///
,reps(500) seed(1001): bsxb, all
bs, eform

*bootstrap SE for Linear Predictor Approach Authority --> largely supervisory, control over organizational resources
cap progr drop bsxb //erase any stored programs
progr define bsxb, rclass //program starts
//step1. run "full" model and save linear predictor
mlogit aut i.man $controls2, base(1) 
cap drop xb
predict xb, outcome(#5) xb
//step2. run models and save parameters of interest relevant for inference
reg xb i.man
return scalar m1_man=_b[1.man]
reg xb i.man $controls1
return scalar m2_man=_b[1.man]
return scalar m2_edu1=_b[1.edu]
return scalar m2_edu2=_b[2.edu]
return scalar m2_edu4=_b[4.edu]
return scalar m2_workexp=_b[workexp]
return scalar m2_tenure=_b[tenure]
reg xb i.man $controls2
return scalar m3_man=_b[1.man]
return scalar m3_edu1=_b[1.edu]
return scalar m3_edu2=_b[2.edu]
return scalar m3_edu4=_b[4.edu]
return scalar m3_workexp=_b[workexp]
return scalar m3_tenure=_b[tenure]
return scalar m3_pt1=_b[1.pt]
return scalar m3_pt2=_b[2.pt]
return scalar m3_pt3=_b[3.pt]
return scalar m3_industry1=_b[1.industry]
return scalar m3_industry2=_b[2.industry]
return scalar m3_industry3=_b[3.industry]
return scalar m3_industry4=_b[4.industry]
return scalar m3_industry5=_b[5.industry]
return scalar m3_industry6=_b[6.industry]
return scalar m3_industry7=_b[7.industry]
return scalar m3_industry8=_b[8.industry]
return scalar m3_industry9=_b[9.industry]
return scalar m3_industry10=_b[10.industry]
return scalar m3_industry11=_b[11.industry]
return scalar m3_industry13=_b[13.industry]
return scalar m3_worksize1=_b[1.worksize]
return scalar m3_worksize2=_b[2.worksize]
return scalar m3_worksize3=_b[3.worksize]
return scalar m3_worksize4=_b[4.worksize]
return scalar m3_worksize5=_b[5.worksize]
return scalar m3_worksize6=_b[6.worksize]
drop xb
end //program ends
//run bootstrap program:
bs m1_man=r(m1_man) m2_man=r(m2_man) m3_man=r(m3_man) ///
m2_edu1=r(m2_edu1) m3_edu1=r(m3_edu1) ///
m2_edu2=r(m2_edu2) m3_edu2=r(m3_edu2) ///
m2_edu4=r(m2_edu4) m3_edu4=r(m3_edu4) ///
m2_workexp=r(m2_workexp) m3_workexp=r(m3_workexp) ///
m2_tenure=r(m2_tenure) m3_tenure=r(m3_tenure) ///
m3_pt1=r(m3_pt1) m3_pt2=r(m3_pt2) m3_pt3=r(m3_pt3) ///
m3_industry1=r(m3_industry1) ///
m3_industry2=r(m3_industry2) ///
m3_industry3=r(m3_industry3) ///
m3_industry4=r(m3_industry4) ///
m3_industry5=r(m3_industry5) ///
m3_industry6=r(m3_industry6) ///
m3_industry7=r(m3_industry7) ///
m3_industry8=r(m3_industry8) ///
m3_industry9=r(m3_industry9) ///
m3_industry10=r(m3_industry10) ///
m3_industry11=r(m3_industry11) ///
m3_industry13=r(m3_industry13) ///
m3_worksize1=r(m3_worksize1) ///
m3_worksize2=r(m3_worksize2) ///
m3_worksize3=r(m3_worksize3) ///
m3_worksize4=r(m3_worksize4) ///
m3_worksize5=r(m3_worksize5) ///
m3_worksize6=r(m3_worksize6) ///
,reps(500) seed(1001): bsxb, all
bs, eform

//end dofile