*==============================================================================*
*                            Description of dofile                             *
/*=============================================================================*

This dofile prepares the data for analysis. 
The structure of this dofile is as follows:

	1. Setting paths
	2. Data preparation
	3. Saving data for analysis (analytic sample)
		
*=============================================================================*/
*                          1. Setting paths                                    *
*==============================================================================*

clear all
set more off
global dir "SET YOUR PATH"
global pathd "$dir/data" 
global paths "$dir/dofiles" 
global pathf "$dir/figures" 
global pathp "$dir/posted" 
global patht "$dir/tables" 

*==============================================================================*
*                                2. Data preparation                           *
*==============================================================================*

** -- NEA -- **
foreach num of numlist 6 5 { //nea2016, nea2015
import spss "PATH TO NEA (2016 AND 2015).sav", clear 
gen year=201`num'
save "$pathd\nea1`num'.dta", replace 
}
import spss "PATH TO NEA 2014.sav", clear //nea2014
gen year=2014
append using "$pathd/nea15.dta" "$pathd/nea16.dta" //appending the three files
rename (RINPERSOONS RINPERSOON) (rinpersoons rinpersoon)  
bysort rinpersoons rinpersoon: egen last=max(year) //for respondents who appear more than once, select observation from later survey
keep if year==last 
save "$pathd/nea.dta", replace  
rm "$pathd/nea16.dta" 
rm "$pathd/nea15.dta"
import spss "PATH TO ADDITIONAL BEROEP VARIABLES NEA 2014-2016.sav", clear //add additional authority variables
rename (RINPERSOONS RINPERSOON) (rinpersoons rinpersoon)
bysort rinpersoons rinpersoon: egen last=max(Jaar) //select observation from later survey
keep if Jaar==last 
merge 1:1 rinpersoons rinpersoon using "$pathd/nea.dta"
drop _merge last Jaar
save "$pathd/nea.dta", replace 
//birth date
use rinpersoons rinpersoon gbageboortejaar gbageboortemaand gbageboortedag using "PATH TO GBAPERSOONTAB 2019.dta", clear
merge 1:1 rinpersoons rinpersoon using "$pathd/nea.dta" 
keep if _merge==3
drop _merge
egen birthymd=concat(gbageboortejaar gbageboortemaand gbageboortedag) //gbageboortedag is always "01"
gen birth=date(birthymd, "YMD") //tranforming birthymd to date variable --> always first of month
format birth %td
//survey date
*NEA 2016 fieldwork is 28 september 2016 - 31 december 2016 (internet)/ 6 januari 2017 (paper)
*NEA 2015 fieldwork is 30 september 2015 - 31 december 2015 
*NEA 2014 fieldwork is 1 october 2014 - 31 january 2015
gen survey=.
foreach num of numlist 4/6 {
replace survey=date("201`num'1231", "YMD") if year==201`num'
}
format survey %td
//date current function 
replace Afl_AncienF=Afl_AncienWG if missing(Afl_AncienF) & !missing(Afl_AncienWG) //missing in function and not in current employer
replace Afl_AncienF=Afl_AncienWG if Afl_AncienF>Afl_AncienWG & !missing(Afl_AncienF, Afl_AncienWG) //function started before employer
gen Afl_AncienF_d=Afl_AncienF*365.25 //Afl_AncienF to number of days
gen datefunction=survey-Afl_AncienF_d
format datefunction %td 
//date current employer
replace Afl_AncienWG=Afl_AncienF if missing(Afl_AncienWG) & !missing(Afl_AncienF) //missing in current employer and not in function
gen Afl_AncienWG_d=Afl_AncienWG*365.25 //Afl_AncienWG to number of days
gen dateemployer=survey-Afl_AncienWG_d
format dateemployer %td 
*check: is date function later than or equal to date employer? 
assert dateemployer<=datefunction if !missing(dateemployer, datefunction)
//education
recode PB_SOI5_HB (1 2=1 "Lower secondary") (3=2 "Higher secondary") (4=3 "Bachelor") (5=4 "Master"), gen(edu)
la var edu "Education" 
//industry
gen industry=Afl_SBI_2008_cat13_CBS
lab define industry 1 "Agriculture & Fishery" 2 "Manufacturing & Energy" 3 "Construction" 4 "Trade" 5 "Transport & Storage" 6 "Catering" 7 "Information & Communication" 8 "Financial Services" 9 "Business Services" 10 "Public Administration" 11 "Education" 12 "Health" 13 "Culture"
la val industry industry 
la var industry "Industry"
//workplace size
recode PersBedr (1 2=1 "less than 10") (3=2 "10-19") (4=3 "20-49") (5=4 "50-99") (6=5 "100-249") (7 8=6 "250-999") (9=7 "1.000 or more"), gen(worksize)
la var worksize "Workplace size" 
//gender
recode M_V (1=1 "Men") (2=0 "Women"), gen(man)
la var man "Man" 
//authority
recode Leiding (1=1 "yes") (2=0 "no"), gen(sup) //supervisory authority
gen share=. //share supervisory tasks 
replace share=1 if sup==0
replace share=2 if sup==1 & UitsLeid==2 & DeelLeid==2
replace share=3 if sup==1 & UitsLeid==2 & DeelLeid==1
replace share=4 if sup==1 & UitsLeid==1
lab define share 1 "none" 2 "some" 3 "mostly" 4 "exclusively"
lab val share share
gen cntrl=. //control over human resources vs. organizational resources 
replace cntrl=1 if PersBeleid==2 & StratBeleid==2
replace cntrl=2 if PersBeleid==1 & StratBeleid==2
replace cntrl=3 if PersBeleid==1 & StratBeleid==1
replace cntrl=4 if PersBeleid==2 & StratBeleid==1
replace cntrl=.a if missing(cntrl) & (share==3 | share==4)
label define cntrl 1 "neither nor" 2 "only human resources" 3 "human and org resources" 4 "only org resources" .a "known to be mostly/exclusively but missing"
lab val cntrl cntrl 
gen aut=.a //combined
replace aut=1 if share==1
replace aut=2 if share==2
replace aut=3 if PersBeleid==2 & StratBeleid==2 //share==3 | share==4
replace aut=4 if PersBeleid==1 & StratBeleid==2 //share==3 | share==4
replace aut=5 if StratBeleid==1 //share==3 | share==4
label define aut 1 "no authority" 2 "some supervisory tasks" 3 "largely supervisory, no control over resources" 4 "largely supervisory, control over human resources" 5 "largely supervisory, control over organizational resources"
lab val aut aut
la var aut "Authority" 
//keep relevant variables
keep rinpersoons rinpersoon year birth survey datefunction dateemployer Afl_AncienF Afl_AncienWG ISCO08_major_group edu PB_SOI5_HB industry worksize man aut 
save "$pathd/nea.dta", replace 

** -- EARNINGS -- **

import spss "PATH TO NEA 2016.sav", clear //select NEA respondents in SPOLIS, 2016 
keep RINPERSOONS RINPERSOON 
rename (RINPERSOON RINPERSOONS) (rinpersoon rinpersoons) 
gen year=2016
save "$pathd\nea16.dta", replace 
use rinpersoons rinpersoon sbeid sdatumaanvangikv sdatumeindeikv slningld saantverlu using "PATH TO SPOLISBUS 2016.dta", clear
merge m:1 rinpersoons rinpersoon using "$pathd/nea16.dta"  
keep if _merge==3
save "$pathd/spolis16.dta", replace  

import spss "PATH TO NEA 2015.sav", clear //select NEA respondents in SPOLIS, 2015
keep RINPERSOONS RINPERSOON 
rename (RINPERSOON RINPERSOONS) (rinpersoon rinpersoons) 
gen year=2015
save "$pathd/nea15.dta", replace 
use rinpersoons rinpersoon sbeid sdatumaanvangikv sdatumeindeikv slningld saantverlu using "PATH TO SPOLISBUS 2015.dta", clear
merge m:1 rinpersoons rinpersoon using "$pathd/nea15.dta"  
keep if _merge==3
save "$pathd/spolis15.dta", replace  

import spss "PATH TO NEA 2014.sav", clear //select NEA respondents in SPOLIS, 2014
keep RINPERSOONS RINPERSOON 
rename (RINPERSOON RINPERSOONS) (rinpersoon rinpersoons) 
gen year=2014
save "$pathd/nea14.dta", replace 
use rinpersoons rinpersoon sbeid sdatumaanvangikv sdatumeindeikv slningld saantverlu using "PATH TO SPOLISBUS 2014.dta", clear
merge m:1 rinpersoons rinpersoon using "$pathd/nea14.dta"  
keep if _merge==3
save "$pathd/spolis14.dta", replace  

foreach num of numlist 4/6 {
use "$pathd/spolis1`num'.dta", clear  
    
//keep jobs that overlap with the survey period
*NEA 2016 fieldwork is 28 september 2016 - 31 december 2016 (internet)/ 6 januari 2017 (paper)
*NEA 2015 fieldwork is 30 september 2015 - 31 december 2015 
*NEA 2014 fieldwork is 1 october 2014 - 31 january 2015
gen aanvang=date(sdatumaanvangikv, "YMD") 
gen eind=date(sdatumeindeikv, "YMD") 
format aanvang eind %td
bys rinpersoons rinpersoon sbeid: egen start=min(aanvang) //start job
bys rinpersoons rinpersoon sbeid: egen end=max(eind) //end job
format start end %td
gen survey=.
replace survey=date("20160928", "YMD") if year==2016 
replace survey=date("20150930", "YMD") if year==2015
replace survey=date("20141001", "YMD") if year==2014
format survey %td
drop if end<survey //drop jobs that ended before the survey fieldwork started 
    
//yearly earnings per employer
bys rinpersoons rinpersoon sbeid: egen yearly_beid=total(slningld)
bys rinpersoons rinpersoon: egen max_yearly=max(yearly_beid) //main job (employer)
keep if yearly_beid==max_yearly //keep main job

//yearly number of hours worked
bys rinpersoons rinpersoon sbeid: egen hours=total(saantverlu)
bys rinpersoons rinpersoon: egen hours_max=max(hours)
keep if hours==hours_max //selecting on hours worked for respondents with two employers (equal earnings)

//hourly earnings
gen earn_2=yearly_beid/hours
gen earn=.
replace earn=earn_2 if year==2016
replace earn=earn_2*1.0032 if year==2015 //adjust for inflation (equivalent salary in 2016); CPI 2016 100.32, 2015 100.00
replace earn=earn_2*1.0092 if year==2014 //adjust for inflation (equivalent salary in 2016); CPI 2016 100.32, 2014 99.40

//keep one observation per respondent (for those already not selected on earnings and hours)
egen tag = tag(rinpersoons rinpersoon)
keep if tag==1

//save data
keep rinpersoons rinpersoon earn year 
save "$pathd/spolis1`num'.dta", replace  
}

//pool 2014-2016
use "$pathd/spolis14.dta", clear 
append using "$pathd/spolis15.dta" "$pathd/spolis16.dta" 

//for respondents who appear more than once, select observation from latest cross-section
bysort rinpersoons rinpersoon: egen last=max(year)
keep if year==last 
drop last
save "$pathd/spolis.dta", replace  
foreach num of numlist 4/6 {
rm "$pathd/spolis1`num'.dta" 
rm "$pathd/nea1`num'.dta"  
}

//add to NEA
use "$pathd/nea.dta", clear 
merge 1:1 rinpersoons rinpersoon using "$pathd/spolis.dta"  
gen log_earn=log(earn) //logged earnings (to address skew)
drop _merge 
save "$pathd/nea.dta", replace

** -- MAIN ACTIVITY AT SURVEY -- **

use rinpersoons rinpersoon aanvsecm eindsecm secm using "PATH TO SECMBUS 2021.dta", clear
merge m:1 rinpersoons rinpersoon using "$pathd/nea.dta"  //merge with NEA
keep if _merge==3
drop _merge

//entry closest to (and starting before) 31 december of each year
gen aanvang=date(aanvsecm, "YMD") //to date
format aanvang %td
bys rinpersoons rinpersoon: egen closest=max(aanvang) if aanvang<survey
format closest %td

//add label to secm 
lab define secm 11 "Werknemer" 12 "Directeur-grootaandeelhouder" 13 "Zelfstandig ondernemer" 14 "Overige zelfstandige" 15 "Meewerkend gezinslid" 21 "Ontvanger werkloosheidsuitkering" 22 "Ontvanger bijstandsuitkering" 23 "Ontvanger uitkering sociale voorz.overig" 24 "Ontvanger uitkering ziekte/AO" 25 "Ontvanger pensioenuitkering" 26	"Nog niet schoolg./schol./stud. met ink." 31 "Nog niet schoolg./schol./stud. geen ink." 32 "Overig zonder inkomen"
destring secm, replace //can't label string vars
lab val secm secm

//identify last secm 
gen secm_sur=secm if aanvang==closest
*replace in all for same rinpersoon 
replace secm_sur=-2 if missing(secm_sur) //stata treats missings as large numbers
bys rinpersoons rinpersoon: egen secms=max(secm_sur)
recode secms 11 12 = 111, gen(se1)
*also replacing in closest, needed below
gen cl=date("19000101", "YMD")
format cl %td
replace closest=cl if missing(closest)
bys rinpersoons rinpersoon: egen close=max(closest)
format close %td //check that earliest is 1999; yes

//for those whose closest begins after 31 october of each year, identify second closest secm
gen oct=.
foreach num of numlist 4/6 {
replace oct=date("201`num'1031", "YMD") if year==201`num'
}
format oct %td
*
bys rinpersoons rinpersoon: egen closest2=max(aanvang) if aanvang<close & close>oct
format closest2 %td
gen secm_sur2=secm if aanvang==closest2
*replace in all for same rinpersoon 
replace secm_sur2=-2 if missing(secm_sur2)
bys rinpersoons rinpersoon: egen secms2=max(secm_sur2)
recode secms2 11 12 = 111, gen(se2)
*also replacing in closest, needed below
replace closest2=cl if missing(closest2)
bys rinpersoons rinpersoon: egen close2=max(closest2)
format close2 %td 

//for those whose closest2 begins after 31 october of the year, identify third closest secm
bys rinpersoons rinpersoon: egen closest3=max(aanvang) if aanvang<close2 & close2>oct
format closest3 %td
gen secm_sur3=secm if aanvang==closest3
*replace in all for same rinpersoon 
replace secm_sur3=-2 if missing(secm_sur3)
bys rinpersoons rinpersoon: egen secms3=max(secm_sur3)
recode secms3 11 12 = 111, gen(se3)
*note: this procedure ends here because there are only two months it could have begun after 31 oct (1 nov & 1 dec) 

//identifier for those who had werknemer or directeur as main activity at least once during the survey period 
gen mainact=0
replace mainact=1 if se1==111 | se2==111 | se3==111
lab define mainact 1 "employee" 0 "other"
lab val mainact mainact

//one observation per respondent
egen tag=tag(rinpersoons rinpersoon)
keep if tag==1

//save data
keep rinpersoons rinpersoon mainact
save "$pathd/mainact.dta", replace  

** -- WORK EXPERIENCE -- **

use rinpersoons rinpersoon aanvsecm eindsecm secm xkoppelscholstudsecm using "PATH TO SECMBUS 2021.dta", clear
merge m:1 rinpersoons rinpersoon using "$pathd/nea.dta" //merge with NEA
keep if _merge==3
drop _merge
fre aanvsecm //19990101 start secmbus

****--- drop everything after 31 december of each year ---****
//string to date start and end variables
gen aanvang=date(aanvsecm, "YMD") 
gen eind=date(eindsecm, "YMD") 
format aanvang eind %td
//entry closest to (and starting before) 31 december of each year
bys rinpersoons rinpersoon: egen closest=max(aanvang) if aanvang<survey
format closest %td
//for those who ended after 31 december of each year (ca 7% ended before 31 dec), make eind survey date
replace eind=survey if aanvang==closest & eind>survey
bys year: fre eind if aanvang==closest //check; okay
//drop entries that ended after survey 
drop if eind>survey 
bys year: fre aanvang eind //check; okay

****--- date start career ---****

//last date respondent registered as student (if applicable) before the survey
gen student=0 //there are no missing cases in secm
replace student=1 if secm=="26" | secm=="31"
bysort rinpersoons rinpersoon: egen lastdatestudent=max(eind / (student==1))
format lastdatestudent %td 
distinct rinpersoon if !missing(lastdatestudent) //student at some point
distinct rinpersoon if missing(lastdatestudent) //not registered as student at any point
//age respondent last time they were registered as student
gen agelaststudent=int((lastdatestudent - birth)/365.25) if !missing(lastdatestudent) //dividing number days by number days in a year

*****
//for (1) students and outside of range, and (2) never registered as student
//calculate if registered as student using xkoppelscholstudsecm variable
//secm registers main activity, xkoppelscholstudsecm registers if student

//was respondent registered as student at any point 1999-2016? 
gen student2=0 //there are no missing cases in xkoppelscholstudsecm
replace student2=1 if xkoppelscholstudsecm=="1" 
//last date the respondent was registered as a student (if applicable)
bysort rinpersoons rinpersoon: egen lastdatestudent2=max(eind / (student2==1))
format lastdatestudent2 %td 
//age respondent last time they were registered as student
gen agelaststudent2=int((lastdatestudent2 - birth)/365.25) //dividing number days by number days in a year

*****
//for those older or younger than range in both agelaststudent & agelaststudent2 or never student, calculate when should have finished highest completed education
gen date17=birth+6205 //6205 days in 17 years //for basisonderwijs and VMBO/MBO/AVO onderbouw
format date17 %td //
gen date20=birth+6935 //6935 days in 19 years --> for HAVO/VWO/MBO
format date20 %td
gen date22=birth+8030 //8030 days in 22 years --> for bachelor
format date22 %td
gen date24=birth+8760 //8760 days in 24 years --> for master
format date24 %td

*****

//start career variable
gen startcareer=. 
format startcareer %td
*first filling in for those who were students at some point 1999-2016
*and were within range for agelaststudent
replace startcareer=lastdatestudent if PB_SOI5_HB==1 & agelaststudent>15 & agelaststudent<18 & !missing(agelaststudent) //16-17
replace startcareer=lastdatestudent if PB_SOI5_HB==2 & agelaststudent>15 & agelaststudent<19 & !missing(agelaststudent) //16-18
replace startcareer=lastdatestudent if PB_SOI5_HB==3 & agelaststudent>15 & agelaststudent<21 & !missing(agelaststudent) //16-20
replace startcareer=lastdatestudent if PB_SOI5_HB==4 & agelaststudent>19 & agelaststudent<25 & !missing(agelaststudent) //20-24
replace startcareer=lastdatestudent if PB_SOI5_HB==5 & agelaststudent>21 & agelaststudent<27 & !missing(agelaststudent) //22-26
*and were out of range for agelaststudent
replace startcareer=date17 if PB_SOI5_HB==1 & (agelaststudent>17 | agelaststudent<16) & !missing(agelaststudent)
replace startcareer=date17 if PB_SOI5_HB==2 & (agelaststudent>18 | agelaststudent<16) & !missing(agelaststudent)
replace startcareer=date20 if PB_SOI5_HB==3 & (agelaststudent>20 | agelaststudent<16) & !missing(agelaststudent)
replace startcareer=date22 if PB_SOI5_HB==4 & (agelaststudent>24 | agelaststudent<20) & !missing(agelaststudent)
replace startcareer=date24 if PB_SOI5_HB==5 & (agelaststudent>26 | agelaststudent<22) & !missing(agelaststudent)
*now replacing for those who were out of range in agelaststudent but in range for agelaststudent2
replace startcareer=lastdatestudent2 if PB_SOI5_HB==1 & (agelaststudent>17 | agelaststudent<16) & (agelaststudent2>15 & agelaststudent2<18) & !missing(agelaststudent, agelaststudent2)
replace startcareer=lastdatestudent2 if PB_SOI5_HB==2 & (agelaststudent>18 | agelaststudent<16) & (agelaststudent2>15 & agelaststudent2<19) & !missing(agelaststudent, agelaststudent2)
replace startcareer=lastdatestudent2 if PB_SOI5_HB==3 & (agelaststudent>20 | agelaststudent<16) & (agelaststudent2>15 & agelaststudent2<21) & !missing(agelaststudent, agelaststudent2)
replace startcareer=lastdatestudent2 if PB_SOI5_HB==4 & (agelaststudent>24 | agelaststudent<20) & (agelaststudent2>19 & agelaststudent2<25) & !missing(agelaststudent, agelaststudent2)
replace startcareer=lastdatestudent2 if PB_SOI5_HB==5 & (agelaststudent>26 | agelaststudent<22) & (agelaststudent2>21 & agelaststudent2<27) & !missing(agelaststudent, agelaststudent2)
*now filling in for those who were not students at any point 1999-2016 according to agelaststudent
replace startcareer=date17 if PB_SOI5_HB==1 & missing(agelaststudent) 
replace startcareer=date17 if PB_SOI5_HB==2 & missing(agelaststudent)
replace startcareer=date20 if PB_SOI5_HB==3 & missing(agelaststudent)
replace startcareer=date22 if PB_SOI5_HB==4 & missing(agelaststudent)
replace startcareer=date24 if PB_SOI5_HB==5 & missing(agelaststudent)
*now replacing for those who were not students in agelaststudent but were in range in agelaststudent2
replace startcareer=lastdatestudent2 if PB_SOI5_HB==1 & (agelaststudent2>15 & agelaststudent2<18) & missing(agelaststudent) & !missing(agelaststudent2)
replace startcareer=lastdatestudent2 if PB_SOI5_HB==2 & (agelaststudent2>15 & agelaststudent2<19) & missing(agelaststudent) & !missing(agelaststudent2)
replace startcareer=lastdatestudent2 if PB_SOI5_HB==3 & (agelaststudent2>15 & agelaststudent2<21) & missing(agelaststudent) & !missing(agelaststudent2)
replace startcareer=lastdatestudent2 if PB_SOI5_HB==4 & (agelaststudent2>19 & agelaststudent2<25) & missing(agelaststudent) & !missing(agelaststudent2)
replace startcareer=lastdatestudent2 if PB_SOI5_HB==5 & (agelaststudent2>21 & agelaststudent2<27) & missing(agelaststudent) & !missing(agelaststudent2)

//age at start career (should be 16 or older for all groups)
gen careerage=int((startcareer-birth)/365.25) 
fre careerage if PB_SOI5_HB==1 //16-17
fre careerage if PB_SOI5_HB==2 //16-18
fre careerage if PB_SOI5_HB==3 //16-20
fre careerage if PB_SOI5_HB==4 //20-24
fre careerage if PB_SOI5_HB==5 //22-26

****--- logical checks ---****
assert dateemployer<=datefunction if !missing(dateemployer, datefunction)
assert datefunction<=survey if !missing(datefunction)
distinct rinpersoon if startcareer<=dateemployer & !missing(startcareer, dateemployer) 
distinct rinpersoon if startcareer>dateemployer & !missing(startcareer, dateemployer) 

****--- drop if date start career missing or before 1 jan 1999 ---****
gen jan99=date("19990101", "YMD") 
format jan99 %td
drop if startcareer==. //the missings here are because of missing on education
drop if startcareer<jan99
drop if startcareer>survey //also drop if after survey

****--- drop if missing on datefunction ---****
drop if datefunction==. 
drop close*
save "$pathd/secmbus.dta", replace

****--- calculate work experience between startcareer and datefunction ---****

**translate startcareer to the aanvang variable**

//identify the first time respondent appears in data
bys rinpersoons rinpersoon: egen first=min(aanvang)
format first %td
distinct rinpersoon if first<=startcareer 
distinct rinpersoon if first>startcareer 

*identify the closest aanvang to startcareer (and the corresponding eind)
bysort rinpersoons rinpersoon: egen closest=max(aanvang) if aanvang<=startcareer
format closest %td

*tripling this observation 
expand 2 if aanvang==closest, gen(ndup) 
expand 2 if aanvang==closest & ndup==0, gen(ndup2) 

*splitting aanvang-eind in two periods by startcareer
//in first duplicate, replace eind to be startcareer-1 day
gen startcareermin1=startcareer-1
format startcareermin1 %td
replace eind=startcareermin1 if ndup==1 
//in second duplicate, replace aanvang to be startcareer
replace aanvang=startcareer if ndup2==1 
//dropping original observation
drop if aanvang==closest & !ndup==1 & !ndup2==1 

*saving these two periods per rinpersoon in a separate dataset
keep if ndup==1 | ndup2==1
drop ndup ndup2 closest
save "$pathd/startcareer.dta", replace

//translate datefunction to the aanvang variable
use "$pathd/secmbus.dta", clear

//identify the last time respondent appears in data
bys rinpersoons rinpersoon: egen last=max(eind)
format last %td
distinct rinpersoon if last>=datefunction 
distinct rinpersoon if last<datefunction 

*identify the eind closest to datefunction (and the corresponding aanvang)
bysort rinpersoon: egen closest=min(eind) if eind>=datefunction
format closest %td

*tripling this observation 
expand 2 if eind==closest, gen(ndup) 
expand 2 if eind==closest & ndup==0, gen(ndup2) 

*splitting aanvang-eind in two periods by datefunction
//in first duplicate, replace aanvang to be datefunction+1 day
gen datefunctionplus1=datefunction+1
format datefunctionplus1 %td
distinct rinpersoon if aanvang==datefunctionplus1 & ndup==1 //1
replace aanvang=datefunctionplus1 if ndup==1 
//in second duplicate, replace eind to be datefunction
distinct rinpersoon if eind==datefunction & ndup2==1 
replace eind=datefunction if ndup2==1 
//dropping original observation
drop if eind==closest & !ndup==1 & !ndup2==1 

*saving these two periods per rinpersoon in a separate dataset
keep if ndup==1 | ndup2==1
drop ndup ndup2 closest
save "$pathd/datefunction.dta", replace

//remove the two 'closest' (see above) observations in secmbus.dta
use "$pathd/secmbus.dta", 

*identify the closest aanvang to startcareer (and the corresponding eind)
bys rinpersoons rinpersoon: egen closest1=max(aanvang) if aanvang<=startcareer
format closest1 %td
drop if aanvang==closest1 
*identify the eind closest to datefunction (and the corresponding aanvang)
bys rinpersoons rinpersoon: egen closest2=min(eind) if eind>=datefunction
format closest2 %td
drop if eind==closest2 

//appending the four observations to secmbus.dta
append using "$pathd/startcareer.dta"
append using "$pathd/datefunction.dta" 

//number of respondents for whom startcareer is before or at datefunction 
distinct rinpersoon if startcareer<=datefunction 
distinct rinpersoon if startcareer>datefunction //these are probably students at the time of the survey
//do all respondents have at least one entry that is larger or equal to startcareer AND smaller or equal to datefunction
bys rinpersoons rinpersoon: egen ifentry=min(aanvang) if aanvang>=startcareer & aanvang<=datefunction
format ifentry %td
distinct rinpersoon if !missing(ifentry) 
*for those who don't, work experience is 0
save "$pathd/secm.dta", replace

**Keep time window between starting career and obtaining current function.**
keep if aanvang>=startcareer
keep if aanvang<=datefunction

**employee marker**
gen employee=0 
replace employee=1 if secm=="11" | secm=="12" | secm=="13" | secm=="14" | secm=="15"
save "$pathd/secmbus.dta", replace

*overall working experience
use "$pathd/secmbus.dta", replace
distinct rinpersoon if startcareer<=datefunction 

//define indicator variable that marks the beginning of each spell of employment 
*i.e.value of employee is 1/goes from 0 to 1
sort rinpersoon aanvang
by rinpersoon: gen byte begin = (employee == 1) & (employee != employee[_n-1])

//define identifier variable that tags distinct spells
by rinpersoon: gen spell = cond(employee == 1, sum(begin), 0) 
*note: 0 indicates a gap between employment spells

//number of spells 
bys rinpersoon: egen spellno = max(spell)

//marking the last observation at the end of each spell
by rinpersoon spell (aanvang), sort: gen byte end = _n == _N

//assigning sequence identifiers within a spell (i need the first)
by rinpersoon spell (aanvang), sort: gen seq = cond(spell, _n, 0)

//date first observation of each spell
bys rinpersoon spell: gen firstdate=aanvang if seq==1 
format firstdate %td

//date last observation of each spell
by rinpersoon spell, sort: gen lastdate=eind if end==1 
format lastdate %td

save "$pathd/workexp.dta", replace

//how many had at least one employment spell? 
distinct rinpersoon if spellno>0 
distinct rinpersoon if spellno==0 //for these, work experience is zero

keep if employee==1 //only employment spells, dropping gaps
keep if seq==1 //first date variable

keep rinpersoons rinpersoon aanvang spell spellno firstdate 
save "$pathd/firstdate.dta", replace

use "$pathd/workexp.dta", clear
sort rinpersoon aanvang
keep rinpersoons rinpersoon aanvang eind employee spell end lastdate 
keep if employee==1 //only employment spells, dropping gaps
keep if end==1 //last date variable

drop employee end aanvang
save "$pathd/lastdate.dta", replace

use "$pathd/firstdate.dta", clear
merge 1:1 rinpersoon spell using "$pathd/lastdate.dta" //all matched
drop _merge

//length of each spell
distinct rinpersoon if firstdate<=lastdate 
distinct rinpersoon if firstdate>lastdate //checked earlier, for these aanvang>eind in original data; error

by rinpersoon spell, sort: gen lengthspell=lastdate-firstdate
replace lengthspell=0 if lengthspell<0 

//work experience
by rinpersoon: gen sumspells=sum(lengthspell)
by rinpersoon: egen workexpdays=max(sumspells)
gen workexp=workexpdays/365.25 //to years

//select one observation per respondent 
egen tag=tag(rinpersoon)
keep if tag==1

keep rinpersoons rinpersoon workexp
save "$pathd/workex.dta", replace 

//replacing 0 in those with 0 work experience
use "$pathd/secm.dta", clear
egen tag=tag(rinpersoons rinpersoon)
keep if tag==1
keep rinpersoons rinpersoon
merge 1:1 rinpersoons rinpersoon using "$pathd/workex.dta"
replace workexp=0 if missing(workexp)

keep rinpersoons rinpersoon workexp
la var workexp "Work experience"
save "$pathd/workexp.dta", replace 

//removing not needed files
rm "$pathd/startcareer.dta" 
rm "$pathd/datefunction.dta"
rm "$pathd/firstdate.dta"
rm "$pathd/lastdate.dta"
rm "$pathd/secmbus.dta"
rm "$pathd/secm.dta"
rm "$pathd/workex.dta"

** -- PART-TIME FACTOR -- ** 

use "PATH TO SECMDTFBUS 2021.dta", clear 
merge m:1 rinpersoons rinpersoon using "$pathd/nea.dta"
keep if _merge==3
drop _merge

//first date in secmdtfbus
gen aanvang=date(aanvsecmdtf, "YMD") //to date
format aanvang %td
fre aanvang //01jan2001 
gen startbus=date("20010101", "YMD") 
format startbus %td

//the first time respondent appears in secmdftbus
bys rinpersoons rinpersoon: egen first=min(aanvang)
format first %td
distinct rinpersoon if first<=datefunction & !missing(datefunction) 
distinct rinpersoon if first>datefunction & !missing(datefunction) 
gen pt_ind=1 if first>datefunction & !missing(datefunction)
distinct rinpersoon if pt_ind==1 
*for how many respondents does datefunction start before 20010101?
distinct rinpersoon if datefunction<startbus & !missing(datefunction) //in these, first>datefunction because datefunction starts before 20010101 

//what is the closest observation before or at datefunction?
bys rinpersoons rinpersoon: egen closest=max(aanvang) if aanvang<=datefunction & !missing(datefunction)
format closest %td 
*replace closest in all (not only for aanvang<=datefunction)
gen cl=date("19000101", "YMD")
format cl %td
replace closest=cl if missing(closest)
bys rinpersoons rinpersoon: egen close=max(closest)
format close %td 
replace close=. if close==cl //replace back
distinct rinpersoon if !missing(close) 

//to keep 
gen tokeep=.
format tokeep %td
replace tokeep=close if !missing(close)
distinct rinpersoon if !missing(tokeep) 
replace tokeep=first if missing(tokeep) & !missing(datefunction)
distinct rinpersoon if !missing(tokeep) 

//keep only relevant observation 
keep if aanvang==tokeep 
fre pt_ind 

//part-time factor
recode secmdtf (0/0.4=1 "0-40%") (0.41/0.60=2 "41-60%") (0.61/0.80=3 "61-80%") (0.81/1=4 "81-100%"), gen(pt)
la var pt "Part-time factor"

keep rinpersoons rinpersoon pt pt_ind
save "$pathd/pttime.dta", replace

** -- APPENDING FILES & FINAL DATA ALTERATIONS -- **

use "$pathd/nea.dta", replace 
foreach var of newlist mainact workexp pttime {
merge 1:1 rinpersoons rinpersoon using "$pathd/`var'.dta"
drop _merge	
}

//tenure with current employer
gen tenure=Afl_AncienWG-Afl_AncienF
replace tenure=workexp if tenure>workexp & !missing(tenure, workexp)
la var tenure "Tenure with current employer"

*==============================================================================*
*                  3. Saving data for analysis (analytic sample)               *
*==============================================================================*

keep if mainact==1 //keep if main activity is working
keep if !missing(workexp) //keep if career started 1999 or later
drop if ISCO08_major_group==0 //drop armed forces occupations
keep if !missing(man, aut, edu, tenure, pt, industry, worksize) //keep if non-missing on vars 
save "$pathp/working.dta", replace 

//end dofile