*==============================================================================*
*                            Description of dofile                             *
/*=============================================================================*

This dofile runs preliminary diagnostics and generates Table 1 presented in the article.
The structure of this dofile is as follows:

	1. Setting paths and opening data
	2. Preliminary diagnostics
	3. Summary statistics (Table 1)
	
*=============================================================================*/
*                        1. Setting paths and opening data                     *
*==============================================================================*

clear all
set more off
global dir "SET YOUR PATH"
global pathd "$dir/data" 
global paths "$dir/dofiles" 
global pathf "$dir/figures" 
global pathp "$dir/posted" 
global patht "$dir/tables" 

use "$pathp/working.dta", clear
	
*=============================================================================*/
*                            2. Preliminary diagnostics                        *
*==============================================================================* 

//Wald test for combining alternatives (needed for multinomial regression)
quietly mlogit aut man ib3.edu workexp tenure ib4.pt ib12.industry ib7.worksize
mlogtest, combine //none of the categories can be combined

//multicolinearity
collin aut man edu workexp tenure pt industry worksize //no multicollinearity

//check for empty cells 
tab aut man, m
foreach var of varlist edu pt industry worksize {
bysort `var': tab aut man
}

*=============================================================================*/
*                	   3. Descriptive statistics (Table 1)      		       *
*==============================================================================*

use "$pathp/working.dta", clear

foreach var of varlist aut edu pt industry worksize {
tab `var', nofreq gen(`var') 
}

eststo women:quietly estpost ///
sum aut? edu? workexp tenure pt? industry1-industry13 worksize? if man==0
eststo men:quietly estpost ///
sum aut? edu? workexp tenure pt? industry1-industry13 worksize? if man==1

esttab women men using "$patht\Table 1.rtf", cells("mean(fmt(2)) sd(fmt(2)) min(fmt(0)) max(fmt(0))") l title("Table 1. Descriptive statistics by gender")addnotes("Source: Statistics Netherlands, own calculations.") replace

//end dofile